import request from '@/utils/request'

// 查询物料类型名称对照列表
export function listDictype(query) {
  return request({
    url: '/guide/dictype/list',
    method: 'get',
    params: query
  })
}

// 查询物料类型名称对照详细
export function getDictype(id) {
  return request({
    url: '/guide/dictype/' + id,
    method: 'get'
  })
}

// 新增物料类型名称对照
export function addDictype(data) {
  return request({
    url: '/guide/dictype',
    method: 'post',
    data: data
  })
}

// 修改物料类型名称对照
export function updateDictype(data) {
  return request({
    url: '/guide/dictype',
    method: 'put',
    data: data
  })
}

// 删除物料类型名称对照
export function delDictype(id) {
  return request({
    url: '/guide/dictype/' + id,
    method: 'delete'
  })
}

// 导出物料类型名称对照
export function exportDictype(query) {
  return request({
    url: '/guide/dictype/export',
    method: 'get',
    params: query
  })
}
// 下载模板
export function importTemplate() {
  return request({
    url: '/guide/dictype/importTemplate',
    method: 'get'
  })
}
// 导入
export function importSignDict(query) {
  return request({
    url: '/guide/dictype/importSignDict',
    method: 'post',
    params: query
  })
}
