<template>
  <div class="app-container">
    <el-form :model="queryParams" ref="queryForm" :inline="true" v-show="showSearch" label-width="88px">
      <el-form-item label="物料类型" prop="signType">
        <el-input
          v-model="queryParams.signType"
          placeholder="请输入物料类型"
          clearable
          size="mini"
          @keyup.enter.native="handleQuery"
          @input="onInput()"
        />
<!---->
      </el-form-item>
<!--      <el-form-item label="ID" prop="pid">-->
<!--        <el-input-->
<!--          v-model="queryParams.pid"-->
<!--          placeholder="请输入物料类型ID"-->
<!--          clearable-->
<!--          size="small"-->
<!--          @keyup.enter.native="handleQuery"-->
<!--          @input="onInput()"-->
<!--        />-->
<!--      </el-form-item>-->
<!--      <el-form-item label="物料名称" prop="signName">-->
<!--        <el-input-->
<!--          v-model="queryParams.signName"-->
<!--          placeholder="请输入物料名称"-->
<!--          clearable-->
<!--          size="small"-->
<!--          @keyup.enter.native="handleQuery"-->
<!--        />-->
<!--      </el-form-item>-->
<!--      <el-form-item label="0 物料类型  1 物料名称" prop="type">-->
<!--        <el-select v-model="queryParams.type" placeholder="请选择0 物料类型  1 物料名称" clearable size="small">-->
<!--          <el-option label="请选择字典生成" value="" />-->
<!--        </el-select>-->
<!--      </el-form-item>-->
      <el-form-item>
        <el-button type="primary" icon="el-icon-search" size="mini" @click="handleQuery">搜索</el-button>
        <el-button icon="el-icon-refresh" size="mini" @click="resetQuery">重置</el-button>
      </el-form-item>
    </el-form>

    <el-row :gutter="10" class="mb8">
      <el-col :span="1.5">
        <el-button
          type="primary"
          plain
          icon="el-icon-plus"
          size="mini"
          @click="handleAdd"
          v-hasPermi="['guide:dictype:add']"
        >新增</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="success"
          plain
          icon="el-icon-edit"
          size="mini"
          :disabled="single"
          @click="handleUpdate"
          v-hasPermi="['guide:dictype:edit']"
        >修改</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="danger"
          plain
          icon="el-icon-delete"
          size="mini"
          :disabled="multiple"
          @click="handleDelete"
          v-hasPermi="['guide:dictype:remove']"
        >删除</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="info"
          plain
          icon="el-icon-upload2"
          size="mini"
          @click="handleImport"
          v-hasPermi="['guide:dictype:add']"
        >导入</el-button>
      </el-col>
      <right-toolbar :showSearch.sync="showSearch" @queryTable="getList"></right-toolbar>
    </el-row>

    <el-table v-loading="loading" :data="dictypeList" @selection-change="handleSelectionChange">
      <el-table-column type="selection" width="55" align="center" />
<!--      <el-table-column label="ID" align="center" prop="id" />-->
      <el-table-column label="物料类型"  prop="signType" >
        <template slot-scope="scope">
          <router-link :to="'/dicttype/data/' + scope.row.id" class="link-type">
            <span>{{ scope.row.signType }}</span>
          </router-link>
        </template>
      </el-table-column>
<!--      <el-table-column label="物料名称" align="center" prop="signName" />-->
<!--      <el-table-column label="0 物料类型  1 物料名称" align="center" prop="type" />-->
      <el-table-column label="描述"  prop="remark" />
      <el-table-column label="创建时间" align="center" prop="createTime" />
<!--      <el-table-column label="扩展" align="center" prop="extend" />-->
      <el-table-column label="操作" align="center" class-name="small-padding fixed-width" width="100px">
        <template slot-scope="scope">
          <el-button
            size="mini"
            type="text"
            icon="el-icon-edit"
            @click="handleUpdate(scope.row)"
            v-hasPermi="['guide:dictype:edit']"
          >修改</el-button>
          <el-button
            size="mini"
            type="text"
            icon="el-icon-delete"
            @click="handleDelete(scope.row)"
            v-hasPermi="['guide:dictype:remove']"
          >删除</el-button>
        </template>
      </el-table-column>
    </el-table>

    <pagination
      v-show="total>0"
      :total="total"
      :page.sync="queryParams.pageNum"
      :limit.sync="queryParams.pageSize"
      @pagination="getList"
    />

    <!-- 添加或修改物料类型名称对照对话框 -->
    <el-dialog :title="title" :visible.sync="open" width="500px" append-to-body>
      <el-form ref="form" :model="form" :rules="rules" size="small" label-width="80px">
        <el-form-item label="物料类型" prop="signType">
          <el-input v-model="form.signType" placeholder="请输入物料类型" />
        </el-form-item>

        <el-form-item label="描述" prop="remark">
          <el-input v-model="form.remark" placeholder="请输入描述" />
        </el-form-item>
      </el-form>

      <div slot="footer" class="dialog-footer">
        <el-button type="primary" @click="submitForm">确 定</el-button>
        <el-button @click="cancel">取 消</el-button>
      </div>
    </el-dialog>
    <el-dialog class="upload" :title="upload.title" :visible.sync="upload.open" width="400px" append-to-body>
      <div style="margin-bottom: 14px;">
        <el-link type="primary" style="font-size:14px" @click="importTemplate">下载模板</el-link>
      </div>

      <el-upload
        ref="upload"
        :limit="1"
        accept=".xlsx, .xls"
        :headers="upload.headers"
        :action="upload.url + '?updateSupport=' + upload.updateSupport"
        :disabled="upload.isUploading"
        :on-progress="handleFileUploadProgress"
        :on-success="handleFileSuccess"
        :auto-upload="false"
        drag
      >
        <i class="el-icon-upload"></i>
        <div class="el-upload__text">
          将文件拖到此处，或
          <em>点击上传</em>
        </div>

        <div class="el-upload__tip" style="color:red" slot="tip">提示：仅允许导入“xls”或“xlsx”格式文件！</div>
      </el-upload>
      <div slot="footer" class="dialog-footer">
        <el-button type="primary" @click="submitFileForm" :disabled="upload.isUploading">确 定</el-button>
        <el-button @click="upload.open = false">取 消</el-button>
      </div>
    </el-dialog>
  </div>
</template>

<script>
import { listDictype, getDictype, delDictype, addDictype, updateDictype, exportDictype,importTemplate,importSignDict } from "@/api/sfa/dictype";
import { getToken } from "@/utils/auth";
export default {
  name: "Dictype",
  components: {
  },
  data() {
    return {
      // 遮罩层
      loading: true,
      // 导出遮罩层
      exportLoading: false,
      // 选中数组
      ids: [],
      // 非单个禁用
      single: true,
      // 非多个禁用
      multiple: true,
      // 显示搜索条件
      showSearch: true,
      // 总条数
      total: 0,
      // 物料类型名称对照表格数据
      dictypeList: [],
      // 弹出层标题
      title: "",
      // 是否显示弹出层
      open: false,
      // 查询参数
      queryParams: {
        pageNum: 1,
        pageSize: 10,
        signType: null,
        pid: null,
        type: 0,
        extend: null
      },
      // 表单参数
      form: {},
      // 表单校验
      rules: {
          signType: [
              { required: true, message: '请输入物料类型', trigger: 'blur' },
          ],
      },
        upload: {
            // 是否显示弹出层（用户导入）
            open: false,
            // 弹出层标题（用户导入）
            title: "",
            // 是否禁用上传
            isUploading: false,
            // 是否更新已经存在的用户数据
            updateSupport: 0,
            // 设置上传的请求头部
            headers: { Authorization: "Bearer " + getToken() },
            // 上传的地址
            url: process.env.VUE_APP_BASE_API + "/common/upload",
            loadProgress: 10,
        },
        upladLoading:null,
    };
  },
  created() {
    this.getList();
  },
  methods: {
      onInput(){
          this.$forceUpdate()
      },
    /** 查询物料类型名称对照列表 */
    getList() {
      this.loading = true;
      listDictype(this.queryParams).then(response => {
        this.dictypeList = response.rows;
        this.total = response.total;
        this.loading = false;
      });
    },
    // 取消按钮
    cancel() {
      this.open = false;
      this.reset();
    },
    // 表单重置
    reset() {
      this.form = {
        id: null,
        createBy: null,
        createTime: null,
        updateBy: null,
        updateTime: null,
        signType: null,
        pid: null,
        signName: null,
        type: null,
        remark: null,
        extend: null
      };
      this.resetForm("form");
    },
    /** 搜索按钮操作 */
    handleQuery() {
      this.queryParams.pageNum = 1;
      this.getList();
    },
    /** 重置按钮操作 */
    resetQuery() {
      this.resetForm("queryForm");
      this.handleQuery();
    },
    // 多选框选中数据
    handleSelectionChange(selection) {
      this.ids = selection.map(item => item.id)
      this.single = selection.length!==1
      this.multiple = !selection.length
    },
    /** 新增按钮操作 */
    handleAdd() {
      this.reset();
      this.open = true;
      this.title = "添加物料类型";
    },
    /** 修改按钮操作 */
    handleUpdate(row) {
      this.reset();
      const id = row.id || this.ids
      getDictype(id).then(response => {
        this.form = response.data;
        this.open = true;
        this.title = "修改物料类型";
      });
    },
    /** 提交按钮 */
    submitForm() {
      this.$refs["form"].validate(valid => {
        if (valid) {
          this.form.type = 0;
          if (this.form.id != null) {
            updateDictype(this.form).then(response => {
              this.$modal.msgSuccess("修改成功");
              this.open = false;
              this.getList();
            });
          } else {
            addDictype(this.form).then(response => {
              this.$modal.msgSuccess("新增成功");
              this.open = false;
              this.getList();
            });
          }
        }
      });
    },
    /** 删除按钮操作 */
    handleDelete(row) {
      const ids = row.id || this.ids;
      this.$confirm('是否确认删除所选数据项?', "警告", {
          confirmButtonText: "确定",
          cancelButtonText: "取消",
          type: "warning"
        }).then(function() {
          return delDictype(ids);
        }).then(() => {
          this.getList();
          this.$modal.msgSuccess("删除成功");
        }).catch(() => {});
    },
    /** 导出按钮操作 */
    handleExport() {
      const queryParams = this.queryParams;
      this.$confirm('是否确认导出所有物料类型名称对照数据项?', "警告", {
          confirmButtonText: "确定",
          cancelButtonText: "取消",
          type: "warning"
        }).then(() => {
          this.exportLoading = true;
          return exportDictype(queryParams);
        }).then(response => {
          this.download(response.msg);
          this.exportLoading = false;
        }).catch(() => {});
    },
      handleImport(){
          this.upload.title = "物料类型导入";
          this.upload.open = true;
      },
      // 文件上传中处理
      handleFileUploadProgress(event, file, fileList) {
          this.upload.isUploading = true;
          this.upladLoading = this.$loading({
              lock: true,
              text: '拼命上传中',
              spinner: 'el-icon-loading',
              background: 'rgba(0, 0, 0, 0.7)'
          });
      },
      // 文件上传成功处理
      handleFileSuccess(response, file, fileList) {
          if(response.code==200){
              let data = {"url":response.fileName};
              importSignDict(data).then(res => {
                  this.upload.open = false;
                  this.upload.isUploading = false;
                  this.upladLoading.close();
                  this.$refs.upload.clearFiles();
                  this.$alert(res.msg, "导入结果", { dangerouslyUseHTMLString: true });
              })
          }else{
              this.upload.open = false;
              this.upload.isUploading = false;
              this.upladLoading.close();
              this.$refs.upload.clearFiles();
              this.$alert(response.msg, "导入结果", { dangerouslyUseHTMLString: true });
          }
          this.getList();
      },
      /** 下载模板操作 */
      importTemplate() {
        importTemplate().then(response => {
          window.location.href = process.env.VUE_APP_BASE_API + "/common/download?fileName=" + encodeURI(response.msg) + "&delete=" + true;

          //this.download(response.msg);
        });
      },
      // 提交上传文件
      submitFileForm() {
          this.$refs.upload.submit();
      },
  }
};
</script>
